/// <reference path='fourslash.ts'/>

////var /**/t2 = { 0: 1, 1: "" };

goTo.marker();
verify.quickInfoIs('var t2: {\n    0: number;\n    1: string;\n}');
